==> haskell-summoner-tui-2.0.1.1-547-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-summoner-tui.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 summoner-tui
version:              2.0.1.1
visibility:           public
id:                   summoner-tui-2.0.1.1-30JC8EhC859Ia13sqyDwgI
key:                  summoner-tui-2.0.1.1-30JC8EhC859Ia13sqyDwgI
license:              MPL-2.0
copyright:            2018-2020 Kowainik
maintainer:           Kowainik <xrom.xkov@gmail.com>
author:               Veronika Romashkina, Dmitrii Kovanikov
stability:            experimental
homepage:             https://github.com/kowainik/summoner
synopsis:
    Tool for scaffolding fully configured batteries-included production-level Haskell projects using TUI.

description:
    Tool for scaffolding fully configured batteries-included production-level Haskell projects using TUI.
    See [README.md](https://github.com/kowainik/summoner#-summoner) for details.

category:             TUI, TUI Tool, Development
abi:                  7540fa8a97470922d0802be8228787d5
exposed:              True
exposed-modules:
    Summoner.Tui Summoner.Tui.Field Summoner.Tui.Form
    Summoner.Tui.GroupBorder Summoner.Tui.Kit Summoner.Tui.Validation
    Summoner.Tui.Widget

hidden-modules:       Paths_summoner_tui
import-dirs:          /usr/lib/ghc-9.2.8/site-local/summoner-tui-2.0.1.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/summoner-tui-2.0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-summoner-tui
hs-libraries:         HSsummoner-tui-2.0.1.1-30JC8EhC859Ia13sqyDwgI
depends:
    base-4.16.4.0 relude-1.2.0.0-JO0hRfVSWVz4YPR7jinT0t
    brick-0.71.1-HIv97AESEI8ESdSzlhRHBs
    colourista-0.1.0.2-35IwqNcCq1C542okgJeRXx directory-1.3.6.2
    microlens-0.4.13.1-HPplyG5VOciEIF62YegSgA
    microlens-th-0.4.3.14-N8oH2Lt1wGBzxrEjsZjaw
    summoner-2.0.1.1-AiGcfY5350d4T0ymLz8BmO
    validation-selective-0.2.0.0-KcImidfqn3l5RlGDBRJiJj
    vty-5.38-LN2UGfOnBbXEHERg1ml1sc

haddock-interfaces:
    /usr/share/doc/haskell-summoner-tui/html/summoner-tui.haddock

haddock-html:         /usr/share/doc/haskell-summoner-tui/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-summoner-tui-2.0.1.1-568-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-summoner-tui.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 summoner-tui
version:              2.0.1.1
visibility:           public
id:                   summoner-tui-2.0.1.1-1Zqmm52iXCC8yk54PKWwN
key:                  summoner-tui-2.0.1.1-1Zqmm52iXCC8yk54PKWwN
license:              MPL-2.0
copyright:            2018-2020 Kowainik
maintainer:           Kowainik <xrom.xkov@gmail.com>
author:               Veronika Romashkina, Dmitrii Kovanikov
stability:            experimental
homepage:             https://github.com/kowainik/summoner
synopsis:
    Tool for scaffolding fully configured batteries-included production-level Haskell projects using TUI.

description:
    Tool for scaffolding fully configured batteries-included production-level Haskell projects using TUI.
    See [README.md](https://github.com/kowainik/summoner#-summoner) for details.

category:             TUI, TUI Tool, Development
abi:                  2cfe617eda981ce94a4870bb05e29a67
exposed:              True
exposed-modules:
    Summoner.Tui Summoner.Tui.Field Summoner.Tui.Form
    Summoner.Tui.GroupBorder Summoner.Tui.Kit Summoner.Tui.Validation
    Summoner.Tui.Widget

hidden-modules:       Paths_summoner_tui
import-dirs:          /usr/lib/ghc-9.2.8/site-local/summoner-tui-2.0.1.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/summoner-tui-2.0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-summoner-tui
hs-libraries:         HSsummoner-tui-2.0.1.1-1Zqmm52iXCC8yk54PKWwN
depends:
    base-4.16.4.0 relude-1.2.0.0-ID2zbQwq5N350mMkETdOCb
    brick-0.71.1-E9cZ1WomhgV6Tea30kqCUq
    colourista-0.1.0.2-4Iz8dcMLyzi4Torlu4KhPb directory-1.3.6.2
    microlens-0.4.13.1-HPplyG5VOciEIF62YegSgA
    microlens-th-0.4.3.15-BttKu46tg2TPgxEFeI4m6
    summoner-2.0.1.1-9s2tT7vSf4R2uiJsx9tyjV
    validation-selective-0.2.0.0-9SDPqhBAve1dCCjr9F9u6
    vty-5.38-CaRMGIrplVnJIAnXF6jMgR

haddock-interfaces:
    /usr/share/doc/haskell-summoner-tui/html/summoner-tui.haddock

haddock-html:         /usr/share/doc/haskell-summoner-tui/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
